@@ -31,6 +31,7 @@ from myst_parser.mocking import (
     MockStateMachine,
     MockingError,
     MockIncludeDirective,
+    MockRSTParser,
 )
 from .parse_directives import parse_directive_text, DirectiveParsingError
 from .parse_html import HTMLImgParser
@@ -363,7 +364,26 @@ class DocutilsRenderer:
             token.info = token.info.strip()
         language = token.info.split()[0] if token.info else ""
 
-        if language.startswith("{") and language.endswith("}"):
+        if not self.config.get("commonmark_only", False) and language == "{eval-rst}":
+            # copy necessary elements (source, line no, env, reporter)
+            newdoc = make_document()
+            newdoc["source"] = self.document["source"]
+            newdoc.settings = self.document.settings
+            newdoc.reporter = self.reporter
+            # pad the line numbers artificially so they offset with the fence block
+            pseudosource = ("\n" * token.map[0]) + token.content
+            # actually parse the rst into our document
+            MockRSTParser().parse(pseudosource, newdoc)
+            for node in newdoc:
+                if node["names"]:
+                    self.document.note_explicit_target(node, node)
+            self.current_node.extend(newdoc[:])
+            return
+        elif (
+            not self.config.get("commonmark_only", False)
+            and language.startswith("{")
+            and language.endswith("}")
+        ):
             return self.render_directive(token)
 
         if not language:
@@ -470,7 +490,7 @@ class DocutilsRenderer:
 
     def render_html_block(self, token):
         node = None
-        if self.config.get("myst_html_img", False):
+        if self.config.get("enable_html_img", False):
             node = HTMLImgParser().parse(token.content, self.document, token.map[0])
         if node is None:
             node = nodes.raw("", token.content, format="html")
@@ -696,6 +716,48 @@ class DocutilsRenderer:
         with self.current_node_context(admonition, append=True):
             self.render_children(token)
 
+    def render_dl_open(self, token):
+        """Render a definition list."""
+        node = nodes.definition_list(classes=["simple", "myst"])
+        self.add_line_and_source_path(node, token)
+        with self.current_node_context(node, append=True):
+            item = None
+            for child in token.children:
+                if child.opening.type == "dt_open":
+                    item = nodes.definition_list_item()
+                    self.add_line_and_source_path(item, child)
+                    with self.current_node_context(item, append=True):
+                        term = nodes.term()
+                        self.add_line_and_source_path(term, child)
+                        with self.current_node_context(term, append=True):
+                            self.render_children(child)
+                elif child.opening.type == "dd_open":
+                    if item is None:
+                        error = self.reporter.error(
+                            (
+                                "Found a definition in a definition list, "
+                                "with no preceding term"
+                            ),
+                            # nodes.literal_block(content, content),
+                            line=child.map[0],
+                        )
+                        self.current_node += [error]
+                    with self.current_node_context(item):
+                        definition = nodes.definition()
+                        self.add_line_and_source_path(definition, child)
+                        with self.current_node_context(definition, append=True):
+                            self.render_children(child)
+                else:
+                    error = self.reporter.error(
+                        (
+                            "Expected a term/definition as a child of a definition list"
+                            f", but found a: {child.opening.type}"
+                        ),
+                        # nodes.literal_block(content, content),
+                        line=child.map[0],
+                    )
+                    self.current_node += [error]
+
     def render_directive(self, token: Token):
         """Render special fenced code blocks as directives."""
         first_line = token.info.split(maxsplit=1)
